#!/bin/sh
#
#  printosnumber.sh  --  part of Rootkit Hunter
#
#  Lookups OS.dat and displays number of current platform.
#
#  This helper is used by another scripts located in current directory.
#
#  Tested under ALTLinux only (derived from Mandrake)
#

function lookup_os_dat() {
    dir0=`dirname $0`
    if [ -e "$dir0/../os.dat" ]; then
	echo $dir0/../os.dat
	return 0
    fi
    if [ -e /etc/rkhunter.conf ]; then
	.   /etc/rkhunter.conf
	if [ -n "$DBDIR" ]; then
	    if [ -e "$DBDIR/os.dat" ]; then
		echo $DBDIR/os.dat
		return 0
	    fi
	fi
    fi
    return 1
}

function read_os_id() {   # Tested on RH-like Linux only
    for f in /etc/*-release; do
	if [ -e "$f" ]; then
	    cat $f
	    return 0
	fi
    done
    return 1
}

function main()
{
    os_dat="`lookup_os_dat`"
    if [ -z "$os_dat" ]; then
	echo "Error: cannot lookup os.dat!" 1>&2
	return 1
    fi
    
    os_id="`read_os_id`"
    if [ -z "$os_id" ]; then
	echo "Error: cannot lookup platform ID" 1>&2
	return 1
    fi
    
    os_record="`grep -- "$os_id" "$os_dat" 2>/dev/null`"
    if [ -z "$os_record" ]; then
	echo "Error: cannot lookup '$os_id' in $os_dat" 1>&2
	return 1
    fi
    
    echo $os_record | cut -d ':' -f1
    return 0
}

main "$@"
